From 24de64725e1000741dc9694464a3c4db4eaa0e36 Mon Sep 17 00:00:00 2001
From: Paolo Bonzini <pbonzini@redhat.com>
Date: Thu, 9 Apr 2015 13:17:21 +0200
Subject: [PATCH 2/2] boot: switch default menu key to ESC

Message-id: <1428585441-26367-3-git-send-email-pbonzini@redhat.com>
Patchwork-id: 64759
O-Subject: [PATCH RHEL7.2 seabios 2/2] boot: switch default menu key to ESC
Bugzilla: 841638
RH-Acked-by: Miroslav Rezanina <mrezanin@redhat.com>
RH-Acked-by: Gerd Hoffmann <kraxel@redhat.com>
RH-Acked-by: Laszlo Ersek <lersek@redhat.com>

On some platforms, F12 may be hard to access; for example, on OS X
machines F9-F12 have been intercepted by the OS for a long time, and
on newer OS X releases function keys are basically gone for good.

Which keys are and are not available depends on the client, not on
the server, but only function keys are usually trapped by terminals.
Hence, using ESC for the boot menu avoids the problems associated
with F12.

Signed-off-by: Paolo Bonzini <pbonzini@redhat.com>
(cherry picked from commit a1ac8861049a5ffefc26ca294293ad666954fcc8)
Signed-off-by: Miroslav Rezanina <mrezanin@redhat.com>

Conflicts:
	docs/Runtime_config.md [not in RHEL].
---
 src/boot.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/boot.c b/src/boot.c
index ac79724..a719349 100644
--- a/src/boot.c
+++ b/src/boot.c
@@ -459,8 +459,8 @@ interactive_bootmenu(void)
         ;
 
     char *bootmsg = romfile_loadfile("etc/boot-menu-message", NULL);
-    int menukey = romfile_loadint("etc/boot-menu-key", 0x86);
-    printf("%s", bootmsg ?: "\nPress F12 for boot menu.\n\n");
+    int menukey = romfile_loadint("etc/boot-menu-key", 1);
+    printf("%s", bootmsg ?: "\nPress ESC for boot menu.\n\n");
     free(bootmsg);
 
     u32 menutime = romfile_loadint("etc/boot-menu-wait", DEFAULT_BOOTMENU_WAIT);
-- 
1.8.3.1

